@@ -8,6 +8,7 @@ use Data::iRealPro::Input;
 use Data::iRealPro::Output;
 use Data::iRealPro::Input::Text;
 use Data::iRealPro::Output::Base;
+use Data::iRealPro::Output::Forum;
 use Data::iRealPro::Output::HTML;
 use Data::iRealPro::Output::Imager;
 use Data::iRealPro::Output::JSON;
@@ -15,4 +16,3 @@ use Data::iRealPro::Output::Text;
 
 # See also:
 # pp/common/PDF_API2_Bundle.pm
-# pp/common/Imager_Bundle.pm
